@@ -1,4 +1,21 @@
-package PFT::Conf v0.5.1;
+# Copyright 2014-2016 - Giovanni Simoni
+#
+# This file is part of PFT.
+#
+# PFT is free software: you can redistribute it and/or modify it under the
+# terms of the GNU General Public License as published by the Free
+# Software Foundation, either version 3 of the License, or (at your
+# option) any later version.
+#
+# PFT is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+# for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with PFT.  If not, see <http://www.gnu.org/licenses/>.
+#
+package PFT::Conf v0.5.3;
 
 =encoding utf8
 
@@ -288,7 +305,14 @@ sub locate {
     my $root;
 
     croak "Not a directory: $cur" unless -d encode(locale_fs => $cur);
-    until ($cur eq rootdir or defined($root)) {
+
+    # No single root directory on Windows. File::Spec->rootdir does not
+    # work as intended. Workaround: $prev is like $cur on the previous
+    # step: we stay on the same directory even going up, we reached the
+    # root. Thanks to Alexandr Ciornii for checking this.
+    my $prev = '';
+    until ($cur eq rootdir or $cur eq $prev or defined($root)) {
+        $prev = $cur;
         if (isroot($cur)) {
             $root = $cur
         } else {
